package cn.iocoder.yudao.module.inspection.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import cn.iocoder.yudao.module.inspection.entity.InspectionAppointment;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-24
 */
@Mapper
public interface InspectionAppointmentMapper extends BaseMapper<InspectionAppointment>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public InspectionAppointment selectInspectionAppointmentById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param inspectionAppointment 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public IPage<InspectionAppointment> selectInspectionAppointmentList(Page<InspectionAppointment> page, @Param("vo") InspectionAppointment inspectionAppointment);

    /**
     * 新增【请填写功能名称】
     *
     * @param inspectionAppointment 【请填写功能名称】
     * @return 结果
     */
    public int insertInspectionAppointment(InspectionAppointment inspectionAppointment);

    /**
     * 修改【请填写功能名称】
     *
     * @param inspectionAppointment 【请填写功能名称】
     * @return 结果
     */
    public int updateInspectionAppointment(InspectionAppointment inspectionAppointment);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteInspectionAppointmentById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectionAppointmentByIds(Long[] ids);
    IPage<InspectionAppointment> getAppointmentList(Page<InspectionAppointment> page, @Param("partnerId") Long partnerId, @Param("phoneNum")String phoneNum);
    List<InspectionAppointment> getAppointmentOwn(@Param("userId") Long userId);


}
